import { Button, Paper, TextField } from "@mui/material";
import style from "./style.module.css";
import CountriesInput, { Country } from "../signin/countriesInput";
import { useMemo, useState } from "react";
import telegram, { sendSignInCode, signIn } from "../../telegram/telegram";

export function HomeSignIn() {
  let [country, setCountry] = useState({} as Country | null);
  let [phone, setPhone] = useState("");
  let [phoneCode, setPhoneCode] = useState("");
  const phoneNumber = useMemo(
    () => (country ? country.country_code : "") + phone,
    [country, phone]
  );

  let [codeHash, setCodeHash] = useState("");

  let onSendCode = () => {
    sendSignInCode(phoneNumber)
      .then((phone_code_hash: string) => {
        setCodeHash(phone_code_hash);
      })
      .catch((error: any) => {
        console.log("error", error);
      });
  };

  let onSignIn = () => {
    signIn(phoneNumber, phoneCode, codeHash)
      .then((user: any) => {
        console.log("user", user);
      })
      .catch((error: any) => {
        console.log("error", error);
      });
  };

  return (
    <Paper
      elevation={0}
      sx={{
        width: "400px",
        display: "flex",
        flexDirection: "column",
        justifyContent: "center",
        alignItems: "center",
        border: "1px solid #e0e0e0",
        padding: "50px 0",
      }}
    >
      <h1 className={style.h1}>登录 / 注册</h1>
      <div className={style.describe}>可通过登录码验证或二维码注册/登录</div>
      {codeHash === "" ? (
        <>
          <div className={style.signInInput}>
            <CountriesInput
              onChange={(value) => {
                setCountry(value);
              }}
            />
            <TextField
              style={{ marginTop: "10px" }}
              label="Phone Number"
              className={style.phone}
              placeholder={"手机号码"}
              value={phone}
              onChange={(e) => setPhone(e.target.value)}
            />
          </div>
          <Button
            size={"large"}
            style={{ alignSelf: "flex-end", marginRight: "50px" }}
            variant="contained"
            onClick={onSendCode}
          >
            下一步
          </Button>
        </>
      ) : (
        <>
          <div className={style.signInInput}>
            <TextField
              style={{ marginTop: "10px" }}
              label="Auth Code"
              className={style.phone}
              placeholder={"验证码"}
              value={phoneCode}
              onChange={(e) => setPhoneCode(e.target.value)}
            />
          </div>
          <div style={{ display: "flex", flexDirection: "row" }}>
            <Button
              size={"large"}
              style={{ alignSelf: "flex-end", marginRight: "50px" }}
              variant="contained"
              onClick={() => {
                setCodeHash("");
              }}
            >
              上一步
            </Button>
            <Button
              size={"large"}
              style={{ alignSelf: "flex-end", marginRight: "50px" }}
              variant="contained"
              onClick={onSignIn}
            >
              登录
            </Button>
          </div>
        </>
      )}

      <div className={style.explain}>
        <h1 className={style.h1}>重要说明</h1>
        <div className={style.explainContent}>
          本服务基于Telegram官方文件上传API，符合
          Telegram用户协议和隐私政策。但请您不要滥
          用此服务，以避免账号被telegram封禁或导致 服务不可使用。
        </div>
      </div>

      <div className={style.describe}>
        未注册账号自动创建为新账号
        <br /> 登录注册均视为已同意 用户协议 和 隐私政策。
      </div>
    </Paper>
  );
}
