import { useEffect, useState } from "react";
import { getMe } from "../../telegram/user";
import { HomeButton } from "../../component/homeButton";
import style from "./style.module.css";
import { Box, Drawer } from "@mui/material";
import { HomeMenu } from "../../component/homeMenu";
import { HomeSignIn } from "../../component/homeSignIn";

function Home() {
  let [isSignIn, setIsSignIn] = useState(false);
  let [isOpenSignIn, setIsOpenSignIn] = useState(false);

  useEffect(function () {
    getMe()
      .then(function (user) {
        // 已登录
        setIsSignIn(true);
      })
      .catch(function (error) {
        if (error.code === 401) {
          // Unauthorized
        }
        console.log(error);
      });
  }, []);

  return (
    <div className={style.box}>
      <div className={style.homeButton}>
        <HomeButton
          isSignIn={isSignIn}
          onNotSignIn={() => {
            setIsOpenSignIn(true);
          }}
        />
      </div>

      <HomeMenu
        className={style.homeMenu}
        isSignIn={isSignIn}
        onOpenSignIn={() => {
          setIsOpenSignIn(true);
        }}
      />

      <Drawer
        anchor={"right"}
        open={isOpenSignIn && !isSignIn}
        onClose={() => {
          setIsOpenSignIn(false);
        }}
        ModalProps={{
          keepMounted: true,
        }}
        transitionDuration={500}
      >
        <Box sx={{ width: "600px", height: "100%" }}>
          <div className={style.homeSignIn}>
            <HomeSignIn />
          </div>
        </Box>
      </Drawer>
    </div>
  );
}

export default Home;
